answer

Function answer 

pub fn answer(database: &CompressedDatabase, query_cipher: &Vector) -> Vector
Computes the matrix-vector product of the packed database and the encrypted query. The output is an encrypted vector that can be decrypted to reveal the records along the column indicated in the query.