pub struct ClientState { /* private fields */ }Expand description
A struct that contains information about the client’s query, including the row and column index, the a-matrix of the database, the side length of the database, the client’s secret key, and the key’s length.